// BVQXPluginInterface.h : general header file for BrainVoyagerQX plugin support
//

#ifndef BVQXPLUGININTERFACE_H
#define BVQXPLUGININTERFACE_H

#include "Plugin_FMR_Header.h"
#include "Plugin_DMR_Header.h"
#include "Plugin_VMR_Header.h"
#include "Plugin_VTC_Header.h"
#include "Plugin_NR_VMP_Header.h"
#include "Plugin_AR_VMP_Header.h"
#include "Plugin_PRT_Header.h"
#include "Plugin_VOI_Header.h"
#include "Plugin_GLM_Header.h"
#include "Plugin_SRF_Header.h"
#include "Plugin_MTC_Header.h"
#include "Plugin_SMP_Header.h"
#include "Plugin_SSM_Header.h"
#include "Plugin_POI_Header.h"

#include "global.h"


// make sure that "MAKE_PLUGIN" is defined here or as a preprocessor definition (this is only important on Windows)
//
#define MAKE_PLUGIN

#if defined OS_WIN32
#ifdef MAKE_PLUGIN
#define PLUGIN_ACCESS __declspec(dllexport)
#else
#define PLUGIN_ACCESS __declspec(dllimport)
#endif
#else
// for all other platforms PLUGIN_ACCESS is empty (not needed)
#define PLUGIN_ACCESS
#endif


class PLUGIN_ACCESS BVQXPluginInterface
{
public:	 
	BVQXPluginInterface() {};
	virtual ~BVQXPluginInterface() {};

	// use this method to execute the plugin (your essential code)
	//
	virtual bool execute() = 0;

	// this method has been introduced with BVQX 2.1 for GUI plugin support: this function will be called in case of GUI plugins once, the execute() method may be called repeatedly from GUI script
	//
	virtual bool initPlugin() = 0;
};


//
// These are typedef's for dynamic access of QX functions
//

// general functions
typedef void (*GetVersionOfBrainVoyagerQXPrototype)(int *, int *, int *);
extern GetVersionOfBrainVoyagerQXPrototype qxGetVersionOfBrainVoyagerQX;

typedef void (*GetBrainVoyagerQXPathPrototype)(char *);
extern GetBrainVoyagerQXPathPrototype qxGetBrainVoyagerQXPath;

typedef void (*GetPluginsPathPrototype)(char *);
extern GetPluginsPathPrototype qxGetPluginsPath;


// input / output
typedef void (*ShowLogPanePrototype)(); // v2.0
extern ShowLogPanePrototype qxShowLogPane;

typedef void (*ShowLogTabPrototype)();
extern ShowLogTabPrototype qxShowLogTab; // deprecated, use "qxShowLogPane"

typedef void (*LogTextPrototype)(const char *);
extern LogTextPrototype qxLogText;

typedef void (*MessageBoxPrototype)(const char *);
extern MessageBoxPrototype qxMessageBox;

typedef int (*YesNoMessageBoxPrototype)(const char *);
extern YesNoMessageBoxPrototype qxYesNoMessageBox;

typedef int (*GetIntegerInputPrototype)(const char *, int, int, int);
extern GetIntegerInputPrototype qxGetIntegerInput;

typedef float (*GetFloatInputPrototype)(const char *, float, float, float);
extern GetFloatInputPrototype qxGetFloatInput;

typedef int (*GetTextInputPrototype)(const char *, const char *, char *);
extern GetTextInputPrototype qxGetTextInput;

typedef int (*GetOpenFileNamePrototype)(const char *, const char *, const char *, char *);
extern GetOpenFileNamePrototype qxGetOpenFileName;

typedef int (*GetSaveFileNamePrototype)(const char *, const char *, const char *, char *);
extern GetSaveFileNamePrototype qxGetSaveFileName;


// GUI
typedef void (*UpdateActiveWindowPrototype)();
extern UpdateActiveWindowPrototype qxUpdateActiveWindow;

typedef void (*ShowBusyCursorPrototype)();
extern ShowBusyCursorPrototype qxShowBusyCursor;

typedef void (*StopBusyCursorPrototype)();
extern StopBusyCursorPrototype qxStopBusyCursor;


// Docs
typedef int (*GetNumberOfDocsInWorkspacePrototype)();
extern GetNumberOfDocsInWorkspacePrototype qxGetNumberOfDocsInWorkspace;

typedef int (*GetDocumentTypePrototype)(int);
extern GetDocumentTypePrototype qxGetDocumentType;

typedef char * (*GetDocumentTypeNamePrototype)(int);
extern GetDocumentTypeNamePrototype qxGetDocumentTypeName;

typedef int (*GetIDOfCurrentDocumentPrototype)();
extern GetIDOfCurrentDocumentPrototype qxGetIDOfCurrentDocument;

typedef void (*SetAsCurrentDocumentPrototype)(int);
extern SetAsCurrentDocumentPrototype qxSetAsCurrentDocument;

typedef int (*CalculateIAMatrixPrototype)(struct FMR_ScannerPosition_Header *, struct VMR_ScannerPosition_Header *, struct VMR_PastTransformations_Header *, float *, float *, float *, float *, float *, float *, float *, float *);
extern CalculateIAMatrixPrototype qxCalculateIAMatrix;

typedef int (*GetTRFParametersFromVolumeToolsDlgPrototype)(float *, float *, float *, float *, float *, float *, float *, float *, float *);
extern GetTRFParametersFromVolumeToolsDlgPrototype qxGetTRFParametersFromVolumeToolsDlg;


// FMR-STC
typedef int (*GetHeaderOfCurrentFMRPrototype)(struct FMR_Header *);
extern GetHeaderOfCurrentFMRPrototype qxGetHeaderOfCurrentFMR;

typedef int (*SetHeaderOfCurrentFMRPrototype)(struct FMR_Header *);
extern SetHeaderOfCurrentFMRPrototype qxSetHeaderOfCurrentFMR;

typedef float ** (*GetSTCFloatDataOfCurrentFMRPrototype)();
extern GetSTCFloatDataOfCurrentFMRPrototype qxGetSTCFloatDataOfCurrentFMR;   // NEW in BVQX v2.0 - use to get float ptr to whole STC data

typedef short ** (*GetSTCIntDataOfCurrentFMRPrototype)();
extern GetSTCIntDataOfCurrentFMRPrototype qxGetSTCIntDataOfCurrentFMR;       // NEW in BVQX v2.0 - use to get short int ptr to whole STC data

typedef short ** (*GetSTCDataOfCurrentFMRPrototype)();
extern GetSTCDataOfCurrentFMRPrototype qxGetSTCDataOfCurrentFMR;             // deprecated in BVQX 2.0 -> use new fns for int or float

typedef int (*SaveFMRPrototype)(const char *);
extern SaveFMRPrototype qxSaveFMR;

typedef int (*SaveFMRAndSTCPrototype)(const char *, const char *);
extern SaveFMRAndSTCPrototype qxSaveFMRAndSTC;

typedef unsigned int (*GetScannerPositionHeaderOfCurrentFMRPrototype)(struct FMR_ScannerPosition_Header *);
extern GetScannerPositionHeaderOfCurrentFMRPrototype qxGetScannerPositionHeaderOfCurrentFMR;

typedef unsigned int (*SetScannerPositionHeaderOfCurrentFMRPrototype)(struct FMR_ScannerPosition_Header *);
extern SetScannerPositionHeaderOfCurrentFMRPrototype qxSetScannerPositionHeaderOfCurrentFMR;


// DMR-DWI
typedef int (*GetHeaderOfCurrentDMRPrototype)(struct DMR_Header *);
extern GetHeaderOfCurrentDMRPrototype qxGetHeaderOfCurrentDMR;

typedef int (*SetHeaderOfCurrentDMRPrototype)(struct DMR_Header *);
extern SetHeaderOfCurrentDMRPrototype qxSetHeaderOfCurrentDMR;

typedef float ** (*GetDWIFloatDataOfCurrentDMRPrototype)();
extern GetDWIFloatDataOfCurrentDMRPrototype qxGetDWIFloatDataOfCurrentDMR;   // NEW in BVQX v2.0 - use to get float ptr to whole STC data

typedef short ** (*GetDWIIntDataOfCurrentDMRPrototype)();
extern GetDWIIntDataOfCurrentDMRPrototype qxGetDWIIntDataOfCurrentDMR;       // NEW in BVQX v2.0 - use to get short int ptr to whole STC data

typedef short ** (*GetDWIDataOfCurrentDMRPrototype)();
extern GetDWIDataOfCurrentDMRPrototype qxGetDWIDataOfCurrentDMR;             // deprecated in BVQX 2.0 -> use new fns for int or float

typedef int (*ConvertDWIFormatOfCurrentDMRPrototype)(int, int);
extern ConvertDWIFormatOfCurrentDMRPrototype qxConvertDWIFormatOfCurrentDMR; // works for both int and float data type

typedef int (*SaveDMRPrototype)(const char *);
extern SaveDMRPrototype qxSaveDMR;

typedef int (*SaveDMRAndDWIPrototype)(const char *, const char *);
extern SaveDMRAndDWIPrototype qxSaveDMRAndDWI;


// VMR
typedef unsigned char * (*GetCurrentVMRPrototype)(int *, int *, int *);
extern GetCurrentVMRPrototype qxGetCurrentVMR;

typedef unsigned int (*GetMainHeaderOfCurrentVMRPrototype)(struct VMR_Header *);
extern GetMainHeaderOfCurrentVMRPrototype qxGetMainHeaderOfCurrentVMR;

typedef unsigned int (*SetMainHeaderOfCurrentVMRPrototype)(struct VMR_Header *);
extern SetMainHeaderOfCurrentVMRPrototype qxSetMainHeaderOfCurrentVMR;

typedef unsigned int (*GetScannerPositionHeaderOfCurrentVMRPrototype)(struct VMR_ScannerPosition_Header *);
extern GetScannerPositionHeaderOfCurrentVMRPrototype qxGetScannerPositionHeaderOfCurrentVMR;

typedef unsigned int (*SetScannerPositionHeaderOfCurrentVMRPrototype)(struct VMR_ScannerPosition_Header *);
extern SetScannerPositionHeaderOfCurrentVMRPrototype qxSetScannerPositionHeaderOfCurrentVMR;

typedef unsigned int (*GetPastTransformationsHeaderOfCurrentVMRPrototype)(struct VMR_PastTransformations_Header *);
extern GetPastTransformationsHeaderOfCurrentVMRPrototype qxGetPastTransformationsHeaderOfCurrentVMR;

typedef unsigned int (*SetPastTransformationsHeaderOfCurrentVMRPrototype)(struct VMR_PastTransformations_Header *);
extern SetPastTransformationsHeaderOfCurrentVMRPrototype qxSetPastTransformationsHeaderOfCurrentVMR;

typedef unsigned int (*ReframeCurrentVMRPrototype)(int, int, int);
extern ReframeCurrentVMRPrototype qxReframeCurrentVMR;

typedef int (*GetCrossPositionOfCurrentVMRPrototype)(int *, int *, int *);
extern GetCrossPositionOfCurrentVMRPrototype qxGetCrossPositionOfCurrentVMR;


// VMP - native resolution
typedef float ** (*GetNRVMPsOfCurrentVMRPrototype)(struct NR_VMPs_Header *);
extern GetNRVMPsOfCurrentVMRPrototype qxGetNRVMPsOfCurrentVMR;

typedef float * (*GetNRVMPOfCurrentVMRPrototype)(int, struct NR_VMP_Header *);
extern GetNRVMPOfCurrentVMRPrototype qxGetNRVMPOfCurrentVMR;

typedef int (*SetNRVMPParametersOfCurrentVMRPrototype)(int, struct NR_VMP_Header *);
extern SetNRVMPParametersOfCurrentVMRPrototype qxSetNRVMPParametersOfCurrentVMR;

typedef int (*LoadNRVMPsToCurrentVMRPrototype)(const char *);
extern LoadNRVMPsToCurrentVMRPrototype qxLoadNRVMPsToCurrentVMR;

typedef int (*AddNRVMPsToCurrentVMRPrototype)(const char *);
extern AddNRVMPsToCurrentVMRPrototype qxAddNRVMPsToCurrentVMR;

typedef void (*SaveNRVMPsOfCurrentVMRPrototype)(const char *);
extern SaveNRVMPsOfCurrentVMRPrototype qxSaveNRVMPsOfCurrentVMR;

typedef int (*CreateNRVMPsForCurrentVMRPrototype)(int, int, int, struct NR_VMPs_Header *);
extern CreateNRVMPsForCurrentVMRPrototype qxCreateNRVMPsForCurrentVMR;

typedef void (*DeleteNRVMPsOfCurrentVMRPrototype)();
extern DeleteNRVMPsOfCurrentVMRPrototype qxDeleteNRVMPsOfCurrentVMR;

typedef int (*DeleteNRVMPMapPrototype)(int);
extern DeleteNRVMPMapPrototype qxDeleteNRVMPMap;

typedef int (*SetNRVMPsParamsDisplayRangePrototype)(struct NR_VMPs_Header *vmps_header);
extern SetNRVMPsParamsDisplayRangePrototype qxSetNRVMPsParamsDisplayRange;


// VMP - anatomical resolution
typedef float ** (*GetARVMPsOfCurrentVMRPrototype)(struct AR_VMPs_Header *);
extern GetARVMPsOfCurrentVMRPrototype qxGetARVMPsOfCurrentVMR;

typedef float * (*GetARVMPOfCurrentVMRPrototype)(int, struct AR_VMP_Header *);
extern GetARVMPOfCurrentVMRPrototype qxGetARVMPOfCurrentVMR;

typedef int (*SetARVMPParametersOfCurrentVMRPrototype)(int, struct AR_VMP_Header *);
extern SetARVMPParametersOfCurrentVMRPrototype qxSetARVMPParametersOfCurrentVMR;

typedef int (*LoadARVMPsToCurrentVMRPrototype)(const char *);
extern LoadARVMPsToCurrentVMRPrototype qxLoadARVMPsToCurrentVMR;

typedef void (*SaveARVMPsOfCurrentVMRPrototype)(const char *);
extern SaveARVMPsOfCurrentVMRPrototype qxSaveARVMPsOfCurrentVMR;

typedef int (*CreateARVMPsForCurrentVMRPrototype)(int, struct AR_VMPs_Header *);
extern CreateARVMPsForCurrentVMRPrototype qxCreateARVMPsForCurrentVMR;

typedef void (*DeleteARVMPsOfCurrentVMRPrototype)();
extern DeleteARVMPsOfCurrentVMRPrototype qxDeleteARVMPsOfCurrentVMR;


// VTC
typedef int (*LinkVTCToCurrentVMRPrototype)(const char *, int);
extern LinkVTCToCurrentVMRPrototype qxLinkVTCToCurrentVMR;

typedef int (*CreateVTCForCurrentVMRPrototype)(int, struct VTC_Header *);
extern CreateVTCForCurrentVMRPrototype qxCreateVTCForCurrentVMR;             // if NULL ptr to VTC_Header, float data created as default - fill header (data type) for more control

typedef int (*GetHeaderOfVTCOfCurrentVMRPrototype)(struct VTC_Header *);
extern GetHeaderOfVTCOfCurrentVMRPrototype qxGetHeaderOfVTCOfCurrentVMR;     // NEW in BVQX v2.0

typedef int (*SetHeaderOfVTCOfCurrentVMRPrototype)(struct VTC_Header *);
extern SetHeaderOfVTCOfCurrentVMRPrototype qxSetHeaderOfVTCOfCurrentVMR;     // NEW in BVQX v2.0

typedef int (*SetVTCParametersOfCurrentVMRPrototype)(struct VTC_Header *);
extern SetVTCParametersOfCurrentVMRPrototype qxSetVTCParametersOfCurrentVMR; // deprecated -> use fn above

typedef float * (*GetVTCFloatDataOfCurrentVMRPrototype)();
extern GetVTCFloatDataOfCurrentVMRPrototype qxGetVTCFloatDataOfCurrentVMR;   // NEW in BVQX v2.0 - use to get float ptr to whole VTC data

typedef short * (*GetVTCIntDataOfCurrentVMRPrototype)();
extern GetVTCIntDataOfCurrentVMRPrototype qxGetVTCIntDataOfCurrentVMR;       // NEW in BVQX v2.0 - use to get short int ptr to whole VTC data

typedef short * (*GetVTCOfCurrentVMRPrototype)(struct VTC_Header *);
extern GetVTCOfCurrentVMRPrototype qxGetVTCOfCurrentVMR;                     // deprecated in BVQX 2.0 -> use fns above

typedef void (*SaveVTCOfCurrentVMRPrototype)(const char *);
extern SaveVTCOfCurrentVMRPrototype qxSaveVTCOfCurrentVMR;

// Multi-VTC
typedef int (*ClearMultiVTCAnalysisPrototype)();
extern ClearMultiVTCAnalysisPrototype qxClearMultiVTCAnalysis;

typedef int (*AddVTCRefForMultiVTCAnalysisPrototype)(const char *);
extern AddVTCRefForMultiVTCAnalysisPrototype qxAddVTCRefForMultiVTCAnalysis;

typedef int (*GetVoxelTimeCourseOfVTCPrototype)(int , int , float *);                 // CHANGED in BVQX v2.0 - provide float ptr, float time series always returned, even if VTC uses short int data type
extern GetVoxelTimeCourseOfVTCPrototype qxGetVoxelTimeCourseOfVTC;

typedef int (*GetVoxelTimeCourseOfVTCsPrototype)(int , float *);                      // CHANGED in BVQX 2.0 - see above
extern GetVoxelTimeCourseOfVTCsPrototype qxGetVoxelTimeCourseOfVTCs;

typedef int (*GetVoxelCoordsTimeCourseOfVTCPrototype)(int , int , int, int, float *); // CHANGED in BVQX 2.0 - see above
extern GetVoxelCoordsTimeCourseOfVTCPrototype qxGetVoxelCoordsTimeCourseOfVTC;

typedef int (*GetVoxelCoordsTimeCourseOfVTCsPrototype)(int , int, int, float *);      // CHANGED in BVQX 2.0 - see above
extern GetVoxelCoordsTimeCourseOfVTCsPrototype qxGetVoxelCoordsTimeCourseOfVTCs;


// GLM
typedef float * (*GetGLMOfCurrentVMRPrototype)(struct GLM_Header *);
extern GetGLMOfCurrentVMRPrototype qxGetGLMOfCurrentVMR;


// MSK
typedef int (*LoadMaskToCurrentVMRPrototype)(const char *);
extern LoadMaskToCurrentVMRPrototype qxLoadMaskToCurrentVMR;

typedef unsigned char * (*GetMaskOfCurrentVMRPrototype)();
extern GetMaskOfCurrentVMRPrototype qxGetMaskOfCurrentVMR;


// SRF
typedef int (*GetScenePrototype)(struct SCENE_Header *);
extern GetScenePrototype qxGetScene;

typedef int (*GetCurrentSRFPrototype)(struct SRF_Header *);
extern GetCurrentSRFPrototype qxGetCurrentSRF;

typedef void (*ReleaseSRFAccessPrototype)(struct SRF_Header *);
extern ReleaseSRFAccessPrototype qxReleaseSRFAccess;

typedef void (*SaveCurrentSRFPrototype)(const char *);
extern SaveCurrentSRFPrototype qxSaveCurrentSRF;

typedef int (*SetCurrentSRFPrototype)(int);
extern SetCurrentSRFPrototype qxSetCurrentSRF;


// SMP
typedef int (*GetSMPsOfCurrentSRFPrototype)(struct SMPs_Header *);
extern GetSMPsOfCurrentSRFPrototype qxGetSMPsOfCurrentSRF;

typedef float * (*GetSMPOfCurrentSRFPrototype)(int, struct SMP_Header *);
extern GetSMPOfCurrentSRFPrototype qxGetSMPOfCurrentSRF;

typedef int (*SetSMPParametersOfCurrentSRFPrototype)(int, struct SMP_Header *);
extern SetSMPParametersOfCurrentSRFPrototype qxSetSMPParametersOfCurrentSRF;

typedef int (*LoadSMPsToCurrentSRFPrototype)(const char *);
extern LoadSMPsToCurrentSRFPrototype qxLoadSMPsToCurrentSRF;

typedef void (*SaveSMPsOfCurrentSRFPrototype)(const char *);
extern SaveSMPsOfCurrentSRFPrototype qxSaveSMPsOfCurrentSRF;

typedef int (*CreateSMPForCurrentSRFPrototype)();
extern CreateSMPForCurrentSRFPrototype qxCreateSMPForCurrentSRF;

typedef void (*DeleteSMPsOfCurrentSRFPrototype)();
extern DeleteSMPsOfCurrentSRFPrototype qxDeleteSMPsOfCurrentSRF;

typedef void (*OverlaySMPsOnSRFPrototype)();
extern OverlaySMPsOnSRFPrototype qxOverlaySMPsOnSRF;


// MTC
typedef int (*LinkMTCToCurrentSRFPrototype)(const char *, int);
extern LinkMTCToCurrentSRFPrototype qxLinkMTCToCurrentSRF;

typedef int (*CreateMTCForCurrentSRFPrototype)(int);
extern CreateMTCForCurrentSRFPrototype qxCreateMTCForCurrentSRF;

typedef float ** (*GetMTCOfCurrentSRFPrototype)(struct MTC_Header *);
extern GetMTCOfCurrentSRFPrototype qxGetMTCOfCurrentSRF;

typedef int (*SetMTCParametersOfCurrentSRFPrototype)(struct MTC_Header *);
extern SetMTCParametersOfCurrentSRFPrototype qxSetMTCParametersOfCurrentSRF;

typedef void (*SaveMTCOfCurrentSRFPrototype)(const char *);
extern SaveMTCOfCurrentSRFPrototype qxSaveMTCOfCurrentSRF;

// Multi-MTC (file-based read access)
typedef int (*ClearMultiMTCRefsOfCurrentSRFPrototype)();
extern ClearMultiMTCRefsOfCurrentSRFPrototype qxClearMultiMTCRefsOfCurrentSRF;

typedef int (*AddMultiMTCRefToCurrentSRFPrototype)(const char *);
extern AddMultiMTCRefToCurrentSRFPrototype qxAddMultiMTCRefToCurrentSRF;

typedef int (*GetVertexTimeCourseOfMTCPrototype)(int , int , float *);
extern GetVertexTimeCourseOfMTCPrototype qxGetVertexTimeCourseOfMTC;

typedef int (*GetVertexTimeCourseOfAllMTCsPrototype)(int , float *);
extern GetVertexTimeCourseOfAllMTCsPrototype qxGetVertexTimeCourseOfAllMTCs;


// SSM
typedef int * (*GetSSMOfCurrentSRFPrototype)(struct SSM_Header *);
extern GetSSMOfCurrentSRFPrototype qxGetSSMOfCurrentSRF;

typedef int (*LoadSSMToCurrentSRFPrototype)(const char *);
extern LoadSSMToCurrentSRFPrototype qxLoadSSMToCurrentSRF;

typedef void (*SaveSSMOfCurrentSRFPrototype)(const char *);
extern SaveSSMOfCurrentSRFPrototype qxSaveSSMOfCurrentSRF;

typedef int (*CreateSSMForCurrentSRFPrototype)();
extern CreateSSMForCurrentSRFPrototype qxCreateSSMForCurrentSRF;

typedef void (*DeleteSSMOfCurrentSRFPrototype)();
extern DeleteSSMOfCurrentSRFPrototype qxDeleteSSMOfCurrentSRF;


// PRT
typedef void (*ClearProtocolPrototype)();
extern ClearProtocolPrototype qxClearProtocol;

typedef int (*LoadProtocolPrototype)(const char *);
extern LoadProtocolPrototype qxLoadProtocol;

typedef int (*SaveProtocolPrototype)(const char *);
extern SaveProtocolPrototype qxSaveProtocol;

typedef int (*GetProtocolPrototype)(struct Protocol_Header *);
extern GetProtocolPrototype qxGetProtocol;

typedef int (*SetProtocolPrototype)(struct Protocol_Header *);
extern SetProtocolPrototype qxSetProtocol;

typedef int (*GetProtocolConditionPrototype)(int, struct ProtocolCondition_Header *);
extern GetProtocolConditionPrototype qxGetProtocolCondition;

typedef int (*AddProtocolConditionPrototype)(struct ProtocolCondition_Header *);
extern AddProtocolConditionPrototype qxAddProtocolCondition;

typedef int (*AddProtocolConditionIntervalPrototype)(int, int, int);
extern AddProtocolConditionIntervalPrototype qxAddProtocolConditionInterval;


// PRED, DM, HRF
typedef int (*ClearDesignMatrixPrototype)();
extern ClearDesignMatrixPrototype qxClearDesignMatrix;

typedef int (*AddPredictorPrototype)(const char *);
extern AddPredictorPrototype qxAddPredictor;

typedef int (*SetPredictorValuesFromConditionPrototype)(const char *, int, float);
extern SetPredictorValuesFromConditionPrototype qxSetPredictorValuesFromCondition;

typedef int (*SetPredictorValuesFromConditionNamePrototype)(const char *, const char *, float);
extern SetPredictorValuesFromConditionNamePrototype qxSetPredictorValuesFromConditionName;

typedef int (*ApplyTwoGammaHRFToPredictorPrototype)(int);
extern ApplyTwoGammaHRFToPredictorPrototype qxApplyTwoGammaHRFToPredictor;

typedef int (*ApplyTwoGammaHRFToPredictorWithNamePrototype)(const char *);
extern ApplyTwoGammaHRFToPredictorWithNamePrototype qxApplyTwoGammaHRFToPredictorWithName;

typedef int (*ApplyBoyntonHRFToPredictorPrototype)(int);
extern ApplyBoyntonHRFToPredictorPrototype qxApplyBoyntonHRFToPredictor;

typedef int (*ApplyBoyntonHRFToPredictorWithNamePrototype)(const char *);
extern ApplyBoyntonHRFToPredictorWithNamePrototype qxApplyBoyntonHRFToPredictorWithName;

typedef float * (*GetPredictorPrototype)(int);
extern GetPredictorPrototype qxGetPredictor;

typedef float * (*GetPredictorByNamePrototype)(const char *);
extern GetPredictorByNamePrototype qxGetPredictorByName;

typedef int (*LoadSingleStudyGLMDesignMatrixPrototype)(const char *);
extern LoadSingleStudyGLMDesignMatrixPrototype qxLoadSingleStudyGLMDesignMatrix;

typedef int (*SaveSingleStudyGLMDesignMatrixPrototype)(const char *);
extern SaveSingleStudyGLMDesignMatrixPrototype qxSaveSingleStudyGLMDesignMatrix;


// VOI
typedef int (*LoadVOIsPrototype)(const char *);
extern LoadVOIsPrototype qxLoadVOIs;

typedef int (*SaveVOIsPrototype)(const char *);
extern SaveVOIsPrototype qxSaveVOIs;

typedef int (*GetVOIsPrototype)(struct VOIs_Header *);
extern GetVOIsPrototype qxGetVOIs;

typedef int * (*GetVOIPrototype)(int, struct VOI_Header *);
extern GetVOIPrototype qxGetVOI;


// POI
typedef int (*LoadPOIsPrototype)(const char *);
extern LoadPOIsPrototype qxLoadPOIs;

typedef int (*SavePOIsPrototype)(const char *);
extern SavePOIsPrototype qxSavePOIs;

typedef int (*GetPOIsPrototype)(struct POIs_Header *);
extern GetPOIsPrototype qxGetPOIs;

typedef int * (*GetPOIPrototype)(int, struct POI_Header *);
extern GetPOIPrototype qxGetPOI;


// Access to (get, set) parameters for exchange with GUI scripts
typedef int (*GetStringParameterPrototype)(char *, char *);
extern GetStringParameterPrototype qxGetStringParameter;

typedef int (*GetIntParameterPrototype)(char *);
extern GetIntParameterPrototype qxGetIntParameter;

typedef float (*GetFloatParameterPrototype)(char *);
extern GetFloatParameterPrototype qxGetFloatParameter;

typedef void (*SetStringParameterPrototype)(char *, char *);
extern SetStringParameterPrototype qxSetStringParameter;

typedef void (*SetIntParameterPrototype)(char *, int);
extern SetIntParameterPrototype qxSetIntParameter;

typedef void (*SetFloatParameterPrototype)(char *, float);
extern SetFloatParameterPrototype qxSetFloatParameter;


// BVQX dialog access (used only internally, for GUI plugins, use new functions above) - deprecated, will be removed in future plugin version
typedef int (*GetDlgStringParameterPrototype)(int, const char *);
extern GetDlgStringParameterPrototype qxGetDlgStringParameter;

typedef int (*GetDlgIntegerParameterPrototype)(int);
extern GetDlgIntegerParameterPrototype qxGetDlgIntegerParameter;

typedef float (*GetDlgFloatParameterPrototype)(int);
extern GetDlgFloatParameterPrototype qxGetDlgFloatParameter;

typedef void (*SetDlgStringOutputParameterPrototype)(int, const char *);
extern SetDlgStringOutputParameterPrototype qxSetDlgStringOutputParameter;

typedef void (*SetDlgIntegerOutputParameterPrototype)(int, int);
extern SetDlgIntegerOutputParameterPrototype qxSetDlgIntegerOutputParameter;

typedef void (*SetDlgFloatOutputParameterPrototype)(int, float);
extern SetDlgFloatOutputParameterPrototype qxSetDlgFloatOutputParameter;

typedef void (*LaunchICADialogPrototype)();
extern LaunchICADialogPrototype qxLaunchICADialog;


// Locally defined functions
extern bool InitQXAccess();
extern bool checkVersionGreaterEqualVersion(int MajorA, int MinorA, int SubMinorA, int MajorB, int MinorB, int SubMinorB);


#endif // BVQXPLUGININTERFACE_H
