																 

#ifndef COLORTOOLS_H
#define COLORTOOLS_H

static const int ANALYSIS_GLM							= 1;
static const int ANALYSIS_GLM_5X2						= 2;
static const int ANALYSIS_GLM_MATCH_EARNINGS			= 3;
static const int ANALYSIS_GLM_OFFERA_PLAYERTYPE			= 4; // 23 pred., added 01-06-10
static const int ANALYSIS_GLM_MATCH_EXP_PLAYERTYPE		= 5; // 18 pred., added 01-06-10
static const int ANALYSIS_GLM_MATCH_EARNINGS_PLAYERTYPE	= 6; // 16 pred., added 01-06-10
static const int ANALYSIS_GLM_EXPEXP_HPC				= 7; // 15 pred., added 13-06-11

static const int GENERATE_COLOR_FROM_NAME = 1;
static const int GENERATE_COLOR_FROM_INDEX = 2;
static const int STARTCOLOR = 1056964608;

/*! 
@function changeMeshColorRGB
@abstract Change a range of colors of a mesh
@param SRF_Header as defined in Plugin_SRF_Header.h
@result Success
@discussion The function could change indices to the convex (0) and concave (1) colors in the headers
but if a hexadecimal RGB value is provided, the function will change the RGB colors. 		\\
This is performed by converting the value to decimals and adding it to the start value 1056964608.
*/
bool changeMeshColorRGB(SRF_Header *srfqx);			

/*! 
@function printColorsOfRangeToLogtab
@abstract Print a range of mesh colors to the BrainVoyager Log tab.
@param SRF_Header as defined in Plugin_SRF_Header.h
@discussion The range will be asked from the user by means of interactive dialogs.
*/
void printColorsOfRangeToLogtab(SRF_Header *srfqx);	

/*! 
@function currentsrfhdr2ascii
@abstract Write some values of the current surface to ascii.
@param SRF_Header as defined in Plugin_SRF_Header.h
@result Ascii containing the header information
@discussion Can be used to write the header values to the BrainVoyager QX Log tab or to a text file.
*/
char *currentsrfhdr2ascii(SRF_Header *srf);	

/*! 
@function hexToDec
@abstract Interactive version of the hexToDec() function. Invokes the non-interactive one.
@result The decimal value
@discussion Used by the function changeMeshColorRGB().
*/
int hexToDec();

/*! 
@function hexToDec
@abstract This function converts hexadecimal to decimal numbers.
@param hexstring A regular string containing the hexadecimal number
@result The decimal value
@discussion Used by the function changeMeshColorRGB().
*/
int hexToDec(char *hexstring);				

/*! 
@function decToHex
@abstract This function converts decimal numbers to hexadecimal.
@param combinedcolor
@param The decimal value
@result hexstring A regular string containing the hexadecimal number
@discussion Used by the function changeMeshColorRGB().
*/
char *decToHex(int combinedcolor, int RGB);
/*!
@function getAutoColor
@abstract Get a hexadecimal color for a condition in one of Sanae's analyses
@param index
@param is5x2 If no, use original number of conditions (14), otherwise use 18 conditions
@discussion Used by the function makeAndSaveReorderedAndColoredProtocol().
*/
int getAutoColor(int index, bool is5x2 = true);
/*!
@function getMultiAutoColor
@abstract Get a hexadecimal color for a condition in one of Sanae's analyses
@param index
@param typeOfAnalysis If 1:, use original number of conditions (14), 2: 5x2 type (18 conditions) 3: match type (16 conditions)
@discussion Used by the function makeAndSaveReorderedAndColoredProtocol().
*/
int getMultiAutoColor(int index, int typeOfAnalysis);


#endif // COLORTOOLS_H
