																 

#ifndef PRES2PROTFUNCS_H
#define PRES2PROTFUNCS_H

#include <vector>
#include "PRES_Header.h"

static int CALC_SUBTRACT = 1;
static int CALC_ADD = 2;
static int COPY_COLOR = 1;
static int COPY_INDEX = 2;
static int COPY_COLOR_AND_INDEX = 3;

typedef struct {

        ProtocolCondition_Header *header;
        int *interval_begin_list;
        int *interval_end_list;
        int conditioncolor;

} protocolstructure;

using namespace std;

/*! 
@function readpres
@abstract Function to read Presentation Log file
@param Name of Presentation Log file
@return Presentation structure
@discussion The function loops twice through the file, once to obtain the number of trials, then to classify  
Optional parameter to read subject column, should be first column [v0.5]. In v0.6 is added that 'Sound' events
are also read. 
*/
presHdr *readpres(char *filename, bool readsubjectcolumn = false, bool includeResponseEvent = true);

/*!
@function convertprotocol
@abstract Function to convert a Presentation log header to BrainVoyager stimulation protocol header
@param presHdr
@param TR in msec 
@param resolution (UNITS_MSEC or UNITS_VOLS)
@param margin (only relevant when resolution is in milliseconds)
@return success
*/
bool convertprotocol(presHdr *pres, int TR, int resolution, int margin = 0, int durationtype = 1);
//bool convertprotocol(presHdr *pres, int TR, int resolution, int margin = 0); 

/*! 
@function checkSimilarityOfConditions
@abstract Function to convert events to conditions and intervals (check)
@param Pointer to Presentation structure in PRES_Header.h
@return New Presentation structure with possibly less conditions but possibly more than 1 intervals per condition. 
@discussion Function under construction, yet is every new Picture stimulus in the Presentation Log file a new condition.
*/
presHdr *checkSimilarityOfConditions(presHdr *pres);

/*!
@function sortConditionsAndIntervals
@abstract Function to sort the total list of trials into clusters of similar conditions
@param presHdr structure with data from Presentation Log file
@param Protocol_Header 
@param TR
@param resolution UNITS_MSEC or UNITS_vols
@param margin
*/
bool sortConditionsAndIntervals(presHdr *conditions, Protocol_Header *prt, int TR, int resolution, int margin = 0, int durationtype = 1);
//bool sortConditionsAndIntervals(presHdr *conditions, Protocol_Header *prt, int TR, int resolution, int margin = 0);

/*!
@function setProtocolProperties
@abstract Function to set colors and pen thickness
@param Protocol_Header *prt
*/
void setProtocolProperties(Protocol_Header *prt);
/*!
@function setProtocolProperties
@abstract Function to set colors and pen thickness
@param Protocol_Header *prt
@param experimentname
*/
void setProtocolProperties(Protocol_Header *prt, char *experimentname);

/*!
@function changeProtocolOffset
@abstract Function to change the protocol offset
@param Protocol_Header *prt
@param calculationtype: volumes or milliseconds 
@param shift
@return
*/
bool changeProtocolOffset(Protocol_Header *prt, int calculationtype, int shift); 
/*!
@function intervalbegin
@abstract compute the begin of the interval
@param resolution UNITS_MSEC or UNITS_VOLS
@param time interval start in tenths of msec
@param TR
@param margin
*/
int intervalbegin(int resolution, double time, int TR, int margin);
/*!
@function intervalend
@abstract compute the end of the interval
@param resolution UNITS_MSEC or UNITS_VOLS
@param start interval start in msec
@param duration time of interval in tenths of msec
@param TR
@param margin
*/
int intervalend(int resolution, int start, double duration, int TR, int margin);
/*!
@function getNewOrderOfConditions
@abstract present dialog to get new order of conditions
@param protocol header
@return string with new order
*/
//char *getNewOrderOfConditions(Protocol_Header *prt);
int getNewOrderOfConditions(Protocol_Header *prt, char *return_txt);
/*!
@function convertConditionListToConditionVector
@abstract convert condition list to map (sic! vector)
@param conditionlist numbers in string separated by commas
@param conditionvector empty list for the numbers
@return success
*/
bool convertConditionListToConditionVector(char *conditionlist, vector<int> &conditionvector);
/*!
@function makeAndSaveReorderedProtocol
@abstract Reorders the conditions
@param protocolheader protocol with original order
@param vector with new order of conditions
@result success
*/
bool makeAndSaveReorderedProtocol(Protocol_Header *origprt, vector<int> &conditionvector);
/*!
@function makeAndSaveReorderedAndColoredProtocol
@abstract Reorders the conditions
@param protocolheader protocol with original order
@param vector with new order of conditions
@result success
*/
bool makeAndSaveReorderedAndColoredProtocol(Protocol_Header *origprt, vector<int> &conditionvector);
/*!
@function makeAndSaveReorderedAndColoredProtocol
@abstract Reorders the conditions
@param protocolheader protocol with original order
@param vector with new order of conditions
@param type of analysis (1=GLM, 2=GLM 5x2, 3=GLM match)
@result success
*/
bool makeAndSaveReorderedAndColoredProtocol(Protocol_Header *origprt, vector<int> &conditionvector, int typeOfAnalysis);

#endif // PRES2PROTFUNCS_H
